Library for UART-mode of the DY-SV5W voice module (and compatible modules)
This is a [no-std] crate which uses a trait to handle I/O. See the two examples on how to implement such an interface to your UART. Although primarily designed for embedded usage, it uses ASYNC to profit from async-frameworks like Embassy.
Structs
Enums
Traits
- DySv5w
SerialIO - This trait needs to be implemented as an interface to the actual hardware interfacing the sound module The UART needs to be set up with 9600,8N1